/*
    This file is part of GnuCode.
    Copyright (C) 2012 Jacob Dawid, jacob.dawid@googlemail.com

    GnuCode is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    GnuCode is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GnuCode. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QFileSystemModel>
#include <QProcess>
#include <QSettings>

namespace Ui
{
  class MainWindow;
}

class MainWindow : public QMainWindow
{
Q_OBJECT public:
  explicit MainWindow (QWidget * parent = 0);
  ~MainWindow ();

private slots:
  void new_project ();
  void open_project ();
  void close_project ();
  void file_activated (QModelIndex index);
  void run_bootstrap ();
  void run_configure ();
  void run_make ();
  void run_install ();
  void run_tarball ();
  void run_package ();
  void process_write_output ();
  void process_write_error ();
  void process_finished (int return_code);
  void process_error (QProcess::ProcessError error);
  void command_return_pressed ();

private:
    Ui::MainWindow * ui;
  QFileSystemModel _file_system_model;
  QDir _current_project_path;
  QProcess _process;
  QSettings *_settings;
};

#endif // MAINWINDOW_H
